@@ -270,7 +270,7 @@ static void convert_from_string(MYSQL_BIND *r_param, char *buffer, size_t len)
     {
       double val= my_atod(buffer, buffer + len, &error);
       *r_param->error= error > 0; /* no need to check for truncation */
-      float8store(r_param->buffer, val);
+      doublestore((uchar *)r_param->buffer, val);
       r_param->buffer_length= sizeof(double);
     } 
     break;
@@ -278,7 +278,7 @@ static void convert_from_string(MYSQL_BIND *r_param, char *buffer, size_t len)
     {
       float val= (float)my_atod(buffer, buffer + len, &error);
       *r_param->error= error > 0; /* no need to check for truncation */
-      float4store(r_param->buffer, val);
+      floatstore((uchar *)r_param->buffer, val);
       r_param->buffer_length= sizeof(float);
     } 
     break;
@@ -918,28 +918,31 @@ static
 void ps_fetch_bin(MYSQL_BIND *r_param, const MYSQL_FIELD *field,
              unsigned char **row)
 {
-  ulong field_length= net_field_length(row);
-  size_t copylen;
+  if (field->charsetnr == 63)
+  {
+    ulong field_length= *r_param->length= net_field_length(row);
+    uchar *current_pos= (*row) + r_param->offset,
+          *end= (*row) + field_length;
+    size_t copylen= 0;
 
-  /* Bug conc-155: For text columns we need to store terminating zero character */
-  if (!(field->flags & BINARY_FLAG) && r_param->buffer_type == MYSQL_TYPE_STRING)
-    field_length++;
-
-  copylen= MIN(field_length, r_param->buffer_length);
-  memcpy(r_param->buffer, *row, copylen);
-  *r_param->error= copylen < field_length;
-
-  /* don't count trailing zero if we fetch into string */
-  if (r_param->buffer_type == MYSQL_TYPE_STRING &&
-      !*r_param->error)
-    field_length--;
-
-  *r_param->length= field_length;
-
-  (*row) += field_length;
+    if (current_pos < end)
+    {
+      copylen= end - current_pos;
+      if (r_param->buffer_length)
+        memcpy(r_param->buffer, current_pos, MIN(copylen, r_param->buffer_length));
+    }
+    if (copylen < r_param->buffer_length &&
+        r_param->buffer_type == MYSQL_TYPE_STRING)
+      ((char *)r_param->buffer)[copylen]= 0;
+    *r_param->error= copylen > r_param->buffer_length;
+    (*row)+= field_length;
+  }
+  else
+    ps_fetch_string(r_param, field, row);
 }
 /* }}} */
 
+
 /* {{{ _mysqlnd_init_ps_subsystem */
 void mysql_init_ps_subsystem(void)
 {
